@@ -472,8 +472,8 @@ class HardwareIOTypeForm(forms.Form):
 
 
 from django.forms.models import inlineformset_factory, BaseModelFormSet, BaseInlineFormSet, BaseModelForm
-from data.models.models import HardwareStats, DataTransformer, DataTransformerConstants, HardwareDataTransformer, \
-    HardwareStatsDataTransformer, DataTransformerTypes
+from data.models.models import ChannelStats, DataTransformer, DataTransformerConstants,  \
+     DataTransformerTypes
 
 
 # DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer, fk_name='data_transformer_parent',
@@ -496,32 +496,32 @@ class DataConstantsTransformerForm(forms.ModelForm):
         fields = ('__all__')
 
 
-class HardwareTransformerForm(forms.ModelForm):
-    id = forms.UUIDField(required=False,
-                         widget=forms.HiddenInput(attrs={'class': 'form-control'}),initial=uuid.uuid4)
-    index = forms.IntegerField(required=False,
-                               widget=forms.HiddenInput(attrs={'class': 'form-control'}),
-                               initial=0)
-    data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformer.objects.all(),
-                                              widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-
-    class Meta:
-        model = HardwareDataTransformer
-        fields = ('__all__')
-
-
-class HardwareStatsTransformerForm(forms.ModelForm):
-    id = forms.UUIDField(required=False,
-                         widget=forms.HiddenInput(attrs={'class': 'form-control'}),initial=uuid.uuid4)
-    index = forms.IntegerField(required=False,
-                               widget=forms.HiddenInput(attrs={'class': 'form-control'}),
-                               initial=0)
-    data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformer.objects.all(),
-                                              widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-
-    class Meta:
-        model = HardwareStatsDataTransformer
-        fields = ('__all__')
+# class HardwareTransformerForm(forms.ModelForm):
+#     id = forms.UUIDField(required=False,
+#                          widget=forms.HiddenInput(attrs={'class': 'form-control'}),initial=uuid.uuid4)
+#     index = forms.IntegerField(required=False,
+#                                widget=forms.HiddenInput(attrs={'class': 'form-control'}),
+#                                initial=0)
+#     data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformer.objects.all(),
+#                                               widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+#
+#     class Meta:
+#         model = HardwareDataTransformer
+#         fields = ('__all__')
+#
+#
+# class HardwareStatsTransformerForm(forms.ModelForm):
+#     id = forms.UUIDField(required=False,
+#                          widget=forms.HiddenInput(attrs={'class': 'form-control'}),initial=uuid.uuid4)
+#     index = forms.IntegerField(required=False,
+#                                widget=forms.HiddenInput(attrs={'class': 'form-control'}),
+#                                initial=0)
+#     data_transformer = forms.ModelChoiceField(required=False, queryset=DataTransformer.objects.all(),
+#                                               widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+#
+#     class Meta:
+#         model = HardwareStatsDataTransformer
+#         fields = ('__all__')
 
 
 class BaseInlineFormSetWithAddMoreButton(BaseInlineFormSet):
@@ -560,8 +560,8 @@ DataConstantsTransformerInlineFormset = inlineformset_factory(DataTransformer, D
                                                               form=DataConstantsTransformerForm, can_delete_extra=True)
 # HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareDataTransformer, extra=1,
 #                                                          form=HardwareTransformerForm, can_delete_extra=True)
-HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=0, formset=BaseInlineFormSetWithAddMoreButton,
-                                                              form=HardwareStatsTransformerForm, can_delete_extra=True)
+# HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=0, formset=BaseInlineFormSetWithAddMoreButton,
+#                                                               form=HardwareStatsTransformerForm, can_delete_extra=True)
 
 def get_values_for_keys_containing(contains, dict):
     valid_keys = []
@@ -669,25 +669,25 @@ class DataTransform(forms.ModelForm):
         )
         self.nested_constants_form.extra = self.instance.data_transformer_constants.count()
 
-        hardware_outputs = self.instance.hardwaredatatransformer_set.first()
-        self.nested_hardware_outputs_form = HardwareTransformerForm(
-            instance=hardware_outputs,
-            data=self.data if self.is_bound else None,
-            files=self.files if self.is_bound else None,
-            prefix=nested_hardware_outputs_form_prefix,
-            initial={'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}
-        )
-
-        self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-            instance=self.instance,
-            queryset=self.instance.hardwarestatsdatatransformer_set,
-            data=self.data if self.is_bound else None,
-            files=self.files if self.is_bound else None,
-            prefix=nested_hardware_stats_form_prefix,
-            initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
-
-        )
-        self.nested_hardware_stats_form.extra = self.instance.hardwarestatsdatatransformer_set.count()
+        # hardware_outputs = self.instance.hardwaredatatransformer_set.first()
+        # self.nested_hardware_outputs_form = HardwareTransformerForm(
+        #     instance=hardware_outputs,
+        #     data=self.data if self.is_bound else None,
+        #     files=self.files if self.is_bound else None,
+        #     prefix=nested_hardware_outputs_form_prefix,
+        #     initial={'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}
+        # )
+        #
+        # self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
+        #     instance=self.instance,
+        #     queryset=self.instance.hardwarestatsdatatransformer_set,
+        #     data=self.data if self.is_bound else None,
+        #     files=self.files if self.is_bound else None,
+        #     prefix=nested_hardware_stats_form_prefix,
+        #     initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
+        #
+        # )
+        # self.nested_hardware_stats_form.extra = self.instance.hardwarestatsdatatransformer_set.count()
 
     def as_p(self):
         print('wtf')
@@ -854,25 +854,25 @@ class DataTransformRoot(forms.ModelForm):
         )
         self.nested_constants_form.extra = self.instance.data_transformer_constants.count()
 
-        hardware_outputs = self.instance.hardwaredatatransformer_set.first()
-        self.nested_hardware_outputs_form = HardwareTransformerForm(
-            instance=hardware_outputs,
-            data=self.data if self.is_bound else None,
-            files=self.files if self.is_bound else None,
-            prefix=nested_hardware_outputs_form_prefix,
-            initial={'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}
-        )
-
-        self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-            instance=self.instance,
-            queryset=self.instance.hardwarestatsdatatransformer_set,
-            data=self.data if self.is_bound else None,
-            files=self.files if self.is_bound else None,
-            prefix=nested_hardware_stats_form_prefix,
-            initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
-
-        )
-        self.nested_hardware_stats_form.extra = self.instance.hardwarestatsdatatransformer_set.count()
+        # hardware_outputs = self.instance.hardwaredatatransformer_set.first()
+        # self.nested_hardware_outputs_form = HardwareTransformerForm(
+        #     instance=hardware_outputs,
+        #     data=self.data if self.is_bound else None,
+        #     files=self.files if self.is_bound else None,
+        #     prefix=nested_hardware_outputs_form_prefix,
+        #     initial={'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}
+        # )
+        #
+        # self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
+        #     instance=self.instance,
+        #     queryset=self.instance.hardwarestatsdatatransformer_set,
+        #     data=self.data if self.is_bound else None,
+        #     files=self.files if self.is_bound else None,
+        #     prefix=nested_hardware_stats_form_prefix,
+        #     initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
+        #
+        # )
+        # self.nested_hardware_stats_form.extra = self.instance.hardwarestatsdatatransformer_set.count()
 
     def as_p(self):
         print('root')
