@@ -299,9 +299,9 @@ class HardwareConfig(models.Model):
         ]
 
 
-class HardwareStats(models.Model):
+class ChannelStats(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
-    hardware = models.ManyToManyField(Channel)
+    channel = models.ManyToManyField(Channel)
 
     type = models.CharField(max_length=255, null=True)
     value = models.FloatField(null=True)
@@ -335,7 +335,8 @@ class DataTransformer(MPTTModel):
         blank=True,
         null=True
     )
-
+    channels = models.ManyToManyField(Channel, blank=True)
+    channel_stats = models.ManyToManyField(ChannelStats, on_delete=models.CASCADE, blank=True, null=True, default=None)
 
     type = models.ForeignKey(DataTransformerTypes, on_delete=models.DO_NOTHING, blank=True, null=True, default=None)
 
@@ -380,48 +381,6 @@ class DataTransformerConstants(models.Model):
         ]
 
 
-class HardwareDataTransformer(models.Model):
-    id = models.UUIDField(primary_key=True, default=uuid.uuid4)
-    hardware = models.ManyToManyField(Channel,blank=True)
-    data_transformer = models.ForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True)
-    index = models.IntegerField(blank=True, null=True, default=None)
-    updated_at = models.DateTimeField(blank=True,auto_now=True)
-    created_at = models.DateTimeField(blank=True,auto_now_add=True)
-
-    def save(self, *args, **kwargs):
-        if not self.created_at:
-            self.created_at = timezone.now()
-        self.updated_at = timezone.now()
-
-        return super().save(*args, **kwargs)
-
-    class Meta:
-        indexes = [
-            models.Index(fields=['id', 'data_transformer']),
-        ]
-
-
-class HardwareStatsDataTransformer(models.Model):
-    id = models.UUIDField(primary_key=True, default=uuid.uuid4,blank=True,null=False)
-    hardware_stat = models.ForeignKey(HardwareStats, on_delete=models.CASCADE, blank=True, null=True, default=None)
-    data_transformer = models.ForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True)
-    index = models.IntegerField(blank=True, null=True, default=None)
-    updated_at = models.DateTimeField(blank=True,auto_now=True)
-    created_at = models.DateTimeField(blank=True,auto_now_add=True)
-
-    def save(self, *args, **kwargs):
-        if not self.created_at:
-            self.created_at = timezone.now()
-        self.updated_at = timezone.now()
-
-        return super().save(*args, **kwargs)
-
-    class Meta:
-        indexes = [
-            models.Index(fields=['id', 'data_transformer']),
-        ]
-
-
 class Calibration(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
     type = models.CharField(max_length=255, null=True)
